@@ -1,11 +1,13 @@
+import logging
 import pyo
 from shakersynth.config import config
 
+log = logging.getLogger(__name__)
+log.setLevel(config.log_level)
+
 
 class RotorSynth():
-    def __init__(self, server: pyo.Server):
-        self.server = server
-
+    def __init__(self):
         envelope0 = pyo.CosTable([
             (0000, 0.0),
             (2000, 1.0),
@@ -29,9 +31,10 @@ class RotorSynth():
         self.osc0 = pyo.Sine(freq=35, mul=self.vca0)
         self.osc1 = pyo.Sine(freq=35, mul=self.vca1)
 
-    def update(self, telemetry):
+    def update(self, telemetry: dict):
         """Update synth parameters based on telemetry."""
-        rpm = telemetry["rotor_rpm"]
+        rpm = self._calculate_rotor_rpm(telemetry)
+
         if rpm == 0:
             rpm = 0.00000001
 
@@ -57,7 +60,6 @@ class RotorSynth():
         # fractional exponential curve so you can still feel the signal at
         # lower RPMs.
         shake_volume = ((telemetry["rotor_rpm_percent"] / 100) ** 0.6)
-        shake_volume *= config.global_volume
 
         self.vca0.setMul(shake_volume)
         self.vca1.setMul(shake_volume)
@@ -74,3 +76,20 @@ class RotorSynth():
     def stop(self):
         self.osc0.stop()
         self.osc1.stop()
+
+    def _calculate_rotor_rpm(self, telemetry: dict):
+        module = telemetry["module"]
+        rpm_percent = telemetry["rotor_rpm_percent"]
+
+        if(module == "mi-8"):
+            # 95 gauge RPM == 192 real rotor RPM. [1, 2]
+            return rpm_percent * (192 / 95)
+        elif(module == "uh-1h"):
+            # 90 gauge RPM == 324 real rotor RPM. [3]
+            return rpm_percent * (324 / 90)
+        else:
+            return 0.00000001
+
+# 1. http://koavia.com/eng/product/helicopter/hvostovye_valy.shtml#2
+# 2. https://www.pprune.org/rotorheads/221789-mil-8-mtv-mtv-1-info.html
+# 3. https://apps.dtic.mil/dtic/tr/fulltext/u2/901787.pdf
